# app_delegate.rb
# RCRunner
#
# Created by Juri Pakaste on 20.11.10.
# Copyright 2010 Juri Pakaste. All rights reserved.

require "tests_view_controller"
require "tests_provider_facade"
require "minitest_provider"

module RCRunner
  class AppDelegate
    attr_writer :window

    def load_test_modules
      @allfiles.each { |file| load(file) }

      tprovider = TestsProviderFacade.new
      tprovider.tests_providers = [MiniTestProvider.new]
      @tests_view_controller.tests_provider = tprovider

      puts "tests: #{tprovider.tests}"
    end
    
    def applicationDidFinishLaunching(notification)
      @tests_view_controller = TestsViewController.alloc.initWithNibName('TestsView', bundle:nil)
      @window.setContentView(@tests_view_controller.view)

      @allfiles = []
      autorun = false
      NSProcessInfo.processInfo.arguments.drop(1).each do |arg|
        if arg == '--autorun'
          autorun = true
          next
        end
        argfiles = Dir.glob(arg)
        @allfiles += argfiles
      end
      @allfiles = @allfiles.uniq
      
      puts "all files: #{@allfiles}"

      self.load_test_modules

      if autorun
        puts "calling run_all"
        @tests_view_controller.run_all
      end
    end

    def reload_menu_clicked(sender)
      self.load_test_modules
    end
    
    # delegate run* menu items to tests_view_controller
    
    def run_all_menu_clicked(sender)
      @tests_view_controller.run_clicked(sender)
    end

    def run_selected_menu_clicked(sender)
      @tests_view_controller.run_selected_clicked(sender)
    end

    def run_failed_menu_clicked(sender)
      @tests_view_controller.run_failed_clicked(sender)
    end
  end
end
