# minitest_provider.rb
# RCRunner
#
# Created by Juri Pakaste on 22.11.10.
# Copyright 2010 Juri Pakaste. All rights reserved.

# Attempt to load the minitest gem if the user has installed it,
# otherwise use the one shipped with MacRuby
begin
  require 'rubygems'
  begin
    gem 'minitest'
  rescue Gem::LoadError
  end
rescue LoadError
end

require 'minitest/unit'
require 'tempfile'

require 'tests_provider_facade'

module RCRunner
  class MiniTestProvider
    def tests
      MiniTest::Unit::TestCase.test_suites.inject([]) do |memo, suite|
        memo += suite.test_methods.map { |meth| Test.new(meth, suite, self) }
      end
    end

    def run(test)
      inst = test.suite.new(test.name)
      inst._assertions = 0
      runner = MiniTestRunner.new

      tmp = Tempfile.new("rcrunner-minitest-")

      realstdout = STDOUT.dup
      realstderr = STDERR.dup

      STDOUT.reopen(tmp)
      STDERR.reopen(tmp)
      
      begin
        inst.run(runner)
      ensure
        STDOUT.reopen(realstdout)
        STDERR.reopen(realstderr)
        tmp.open()
        runner.result.log = tmp.read()
        tmp.close(true)
      end
      runner.result
    end
  end


  class MiniTestRunner
    attr_reader :start_time, :result
    
    def initialize
      @start_time = Time.now
      @result = TestResult.new(:success, "", [], "")
    end

    def puke(klass, meth, exc)
      @result = case exc
                when MiniTest::Skip then TestResult.new(:skip, "", [], "")
                when MiniTest::Assertion then
                  TestResult.new(:failure, exc.message, exc.backtrace, "")
                else
                  TestResult.new(:error, exc.message, exc.backtrace, "")
                end
    end
  end
end

